<?php
    if( !isset($reviews) || !is_array($reviews) ){
        return;
    }
    $slideOptions = [
        'slidesPerView' => $options['desktop'],
        'pagination' => filter_var( $options['dots'], FILTER_VALIDATE_BOOLEAN ) === false ? false : ['el' => ".swiper-pagination", 'dynamicBullets' => false, 'clickable' => true ],
        'paginationClickable' => filter_var( $options['dots'], FILTER_VALIDATE_BOOLEAN ) === false ? false : true,
        'spaceBetween'  => intval( $options['space'] ),
        'speed'         => intval( $options['speed'] ),
        'loop'          => intval( $options['loop'] ),
        'autoplay'      => filter_var( $options['autoplay'], FILTER_VALIDATE_BOOLEAN ) === false ? false : [ 'delay' => $options['delay'], 'disableOnInteraction' => false ],
        'breakpoints'   => [
            '1024' => [
                'slidesPerView' => $options['desktop'],
            ],
            '768' => [
                'slidesPerView' => $options['tablet'],
            ],
            '425' => [
                'slidesPerView' => $options['mobile'],
            ],
            '375' => [
                'slidesPerView' => $options['mobile'],
            ],
            '320' => [
                'slidesPerView' => $options['mobile'],
            ]
        ]
    ];
    if($options['arrows'] == 1) {
        $slideOptions['navigation'] = [
            'nextEl' => '.swiper-button-next',
            'prevEl' => '.swiper-button-prev',
        ];
    }
    $wraperClass = 'reviews-swiper-wrapper';
    $options['equalHeight'] ? $wraperClass .= ' item-height_equal ' : '';
?>
<div class="<?php esc_attr_e($wraperClass) ?>" style="<?php echo sprintf('--gap: %spx', $options['space']); ?>">

    <div class="swiper reviews-sorted slide-layout reviews-slider" data-options='<?php echo json_encode($slideOptions) ?>'>
        <div class="swiper-wrapper">

            <!-- Slides -->
            <?php foreach($reviews as $review): ?>
                <?php if($review->status == 'Published'){ ?>
                <div class="swiper-slide">
                    <div class="inner">

                        <div class="swipe-content">
                        
                            <div class="reviewBody">
                                <?php echo wpautop(wp_kses_data(stripslashes($review->content))); ?>
                            </div>
                        </div>

                        <div class="swipe-footer">
                            <?php
                                $created = date("F d, Y", strtotime($review->created_at));  
                            ?>
                            
                            <div>
                                <span class="author"><?php printf('%s %s', esc_html($review->authorfname), esc_html($review->authorlname) ); ?></span> 
                                - <span class="date"><?php esc_html_e( $created ); ?></span>
                            </div>
                            <div class="rs-rating" style="<?php printf('--rating:%s', esc_attr($review->rating) ); ?>" 
                                aria-label="<?php printf( __('Rating of this product is %s out of 5.', 'reviews-sorted'), esc_attr( $review->rating )); ?>">
                                <span style="display:none;"><?php printf( __('%s Stars', 'reviews-sorted'), esc_html( $review->rating)); ?></span>
                            </div>
                        </div>

                    </div>
                </div><!-- .swiper-slide -->
                <?php } ?>
            <?php endforeach; ?>
        </div><!-- .swiper-wrapper -->
        
        <div class="swiper-pagination"></div>
        <!-- navigation buttons -->
        <?php if ( $options['arrows'] ) : ?>
            <div class="swiper-button-prev"></div>
            <div class="swiper-button-next"></div>
        <?php endif ?>

        <!-- pagination -->
        <?php if ( $options['dots'] ) : ?>
            <div class="swiper-pagination"></div>
        <?php endif ?>

    </div><!-- .swiper -->

</div>
